# StreamOptions


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**include_usage** | **bool** |  | [optional] 

## Example

```python
from _generated.models.stream_options import StreamOptions

# TODO update the JSON string below
json = "{}"
# create an instance of StreamOptions from a JSON string
stream_options_instance = StreamOptions.from_json(json)
# print the JSON string representation of the object
print(StreamOptions.to_json())

# convert the object into a dict
stream_options_dict = stream_options_instance.to_dict()
# create an instance of StreamOptions from a dict
stream_options_from_dict = StreamOptions.from_dict(stream_options_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


